@@ -120,11 +120,33 @@ sub current_status {
     return $a->status;
 }
 
+sub current_status_async {
+    my $self = shift;
+    my $to_caller = VM::EC2->condvar;
+
+    my $cv = $self->aws->describe_volumes_async($self->volumeId);
+
+    $cv->cb(sub {
+	my $v   = shift->recv;
+	my $a   = $v->attachment;
+	if ($a) {
+	    $to_caller->send($a->status);
+	} else {
+	    $to_caller->send('detached');
+	}
+	    
+	    });
+
+    return $to_caller;
+}
+
+
 sub refresh {
     my $self = shift;
     my $v    = $self->aws->describe_volumes($self->volumeId);
-    my $a    = $v->attachment;
-    %$self   = %$a;
+    my $a    = $v && $v->attachment;
+    %$self   = %$a if $a;
+    return defined $a;
 }
 
 sub deviceName { shift->device }
